@@ -21,8 +21,8 @@ viscm_parameters = {
     "max_Jp": 94.7771696638,
 }
 
-luts = (
-    np.array(
+luts = np.transpose(
+    (
         [
             0.44131774,
             0.44370177,
@@ -280,9 +280,7 @@ luts = (
             0.97790967,
             0.986926,
             0.99464852,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.05626182,
             0.06063603,
@@ -540,9 +538,7 @@ luts = (
             0.94575723,
             0.94660423,
             0.94788672,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.04951266,
             0.06083219,
@@ -800,7 +796,6 @@ luts = (
             0.2341978,
             0.25223614,
             0.2722682,
-        ]
-    ),
-    np.ones(256),
+        ],
+    )
 )
