@@ -21,8 +21,8 @@ viscm_parameters = {
     "max_Jp": 95,
 }
 
-luts = (
-    np.array(
+luts = np.transpose(
+    (
         [
             0.07873808,
             0.08503098,
@@ -280,9 +280,7 @@ luts = (
             0.96451696,
             0.97201416,
             0.97959794,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.02380049,
             0.02762946,
@@ -540,9 +538,7 @@ luts = (
             0.94151285,
             0.9446259,
             0.94771918,
-        ]
-    ),
-    np.array(
+        ],
         [
             0.45890713,
             0.46137905,
@@ -800,7 +796,6 @@ luts = (
             0.52734442,
             0.52433316,
             0.52118636,
-        ]
-    ),
-    np.ones(256),
+        ],
+    )
 )
