@@ -1,4 +1,4 @@
-#!/usr/bin/env python3
+#!/usr/bin/env python
 import sys
 
 if sys.version_info >= (3, 11):
@@ -6,11 +6,11 @@ if sys.version_info >= (3, 11):
 else:
     import tomli as tomllib
 
-import tomli_w
-
 import re
 from collections.abc import MutableMapping
 
+import tomli_w
+
 
 def hardpin(s: str) -> str:
     sep = re.search("(>|=|<|~)", s)
@@ -36,7 +36,7 @@ if __name__ == "__main__":
     with open("pyproject.toml", "rb") as fh:
         conf = tomllib.load(fh)
     hardpin_mapping(conf["project"], "dependencies")
-    for target in conf["project"]["optional-dependencies"]:
+    for target in conf["project"].get("optional-dependencies", {}):
         hardpin_mapping(conf["project"]["optional-dependencies"], target)
 
     with open("pyproject.toml", "wb") as fhw:
